California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 70 - TRIBAL GAMING COMPACTS. EXCLUSIVE GAMING RIGHTS. CONTRIBUTIONS TO STATE. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1270533 | STOP UNLIMITED CASINOS - NO ON 70, A COALITION OF BUSINESS LABOR AND GAMING | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1266181 | NO ON 68 & 70 - GOVERNOR SCHWARZENEGGER'S COMMITTEE FOR FAIR SHARE GAMING AGREEMENTS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1269307 | UNITE HERE, AFL- CIO, NO ON PROPOSITIONS 68 AND 70 COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1262916 | YES ON 70, MAJOR FUNDING BY AGUA CALIENTE BAND OF CAHUILLA INDIANS, SAN MANUEL BAND OF MISSION INDIANS AND OTHER INDIAN GAMING TRIBES | SUPPORT